import { ref } from "vue";
import { useCookies } from '@vueuse/integrations/useCookies'
import { useFetch } from "./useFetch.ts";
import { GetUsernameResponse } from "../types/user.ts";

const cookies = useCookies(['session']);
const { get } = useFetch();

const sessionId = ref<string>();
const username = ref<string>();

export const useSession = () => {
    const setSessionId = (id: string) => {
        cookies.set('session', id);
        sessionId.value = id;
    }

    const getSessionId = (): string | undefined => sessionId.value;

    const initializeSessionId = (): void => {
        if (!sessionId.value) {
            const cookieSessionId = cookies.get('session');
            if (cookieSessionId) {
                setSessionId(cookieSessionId);
            }
        }
    };

    const setUsername = (name: string | undefined): void => {
        username.value = name;
    }

    const getUsername = (): string | undefined => username.value;

    const initializeUsername = async () => {
        if (!username.value) {
            const cookieSessionId = cookies.get('session');
            if (cookieSessionId) {
                const username = await get<GetUsernameResponse>(`/sessions/get_username?session_id=${ cookieSessionId }`);
                setUsername(username.username);
            }
        }
    }

    return { initializeSessionId, setSessionId, getSessionId, setUsername, getUsername, initializeUsername };
}