import { useFilterStore } from "../stores/filterStore.ts";
import { Ref } from "vue";

type RefState<T> = {
    [K in keyof T]: Ref<T[K]>
}
type FilterStoreState = ReturnType<typeof useFilterStore>['$state'];
type Callback = (...args: RefState<FilterStoreState>[]) => void

class EventBus {
    private events: { [key: string]: Callback[] } = {}

    on(event: string, callback: Callback) {
        if (!this.events[event]) {
            this.events[event] = []
        }
        this.events[event].push(callback)
    }

    off(event: string) {
        delete this.events[event];
    }

    emit(event: string, ...args: any[]) {
        if (this.events[event]) {
            this.events[event].forEach(callback => callback(...args))
        }
    }
}

export const eventBus = new EventBus()
